referrerpolicy=no-referrer-when-downgrade

transfer_ownership

Function transfer_ownership 

pub fn transfer_ownership<T: Config<I>, I: 'static>(
    id: T::AssetIdParameter,
    owner: <<T as Config>::Lookup as StaticLookup>::Source,
)
Change the Owner of an asset.

Origin must be Signed and the sender should be the Owner of the asset id.

The asset (and metadata) deposit is moved from the current to the new owner. Fails with Error::IncompleteDepositTransfer if a lock or freeze on the current owner blocks the full transfer; clear it and retry.

  • id: The identifier of the asset.
  • owner: The new Owner of this asset.

Emits OwnerChanged.

Weight: O(1)

Warning: Doc-Only

This function is an automatically generated, and is doc-only, uncallable stub. See the real version in Pallet::transfer_ownership.